@@ -1,23 +1,18 @@
 package httptransport
 
 import (
-	"encoding/json"
 	"net/http"
 
-	"github.com/quay/clair/v4/indexer"
 	"github.com/quay/claircore"
 	"github.com/quay/claircore/pkg/jsonerr"
-	"github.com/rs/zerolog"
+
+	"github.com/quay/clair/v4/indexer"
+	"github.com/quay/clair/v4/internal/codec"
 )
 
 func AffectedManifestHandler(serv indexer.Affected) http.HandlerFunc {
 	return func(w http.ResponseWriter, r *http.Request) {
 		ctx := r.Context()
-		log := zerolog.Ctx(ctx).With().
-			Str("method", "index").
-			Logger()
-		ctx = log.WithContext(ctx)
-
 		if r.Method != http.MethodPost {
 			resp := &jsonerr.Response{
 				Code:    "method-not-allowed",
@@ -30,8 +25,9 @@ func AffectedManifestHandler(serv indexer.Affected) http.HandlerFunc {
 		var vulnerabilities struct {
 			V []claircore.Vulnerability `json:"vulnerabilities"`
 		}
-		err := json.NewDecoder(r.Body).Decode(&vulnerabilities)
-		if err != nil {
+		dec := codec.GetDecoder(r.Body)
+		defer codec.PutDecoder(dec)
+		if err := dec.Decode(&vulnerabilities); err != nil {
 			resp := &jsonerr.Response{
 				Code:    "bad-request",
 				Message: err.Error(),
@@ -51,7 +47,9 @@ func AffectedManifestHandler(serv indexer.Affected) http.HandlerFunc {
 		}
 
 		defer writerError(w, &err)
-		err = json.NewEncoder(w).Encode(affected)
+		enc := codec.GetEncoder(w)
+		defer codec.PutEncoder(enc)
+		err = enc.Encode(affected)
 		return
 	}
 }
